spacepy.datamodel.toHTML — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- datamodel - easy to use general data model »

# spacepy.datamodel.toHTML

`spacepy.datamodel.` `toHTML`(fname, SDobject, attrs=(), varLinks=False, linkFormat=None, echo=False, tableTag='<table border="1">')

  Create an HTML dump of the structure of a spacedata

  Parameters: | fname : str Filename to write to SDobject : spacepy.datamodel.SpaceData SpaceData with associated attributes and variables in dmarrays
  Other Parameters:
  | overwrite : bool (optional) allow overwrite of an existing target file (default True) mode : str (optional) HDF5 file open mode (a, w, r) (default ‘a’) echo : bool echo the html to the screen varLinks : bool make the variable name a link to a stub page

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- datamodel - easy to use general data model »